#!/bin/sh

# this simple script decodes a few WSJ0 utterances using the AURORA 
# evaluation models produced at ISIP
# 
echo "INFO: Preparing directories..."

# clean up the experiment directory if it already exists
#
rm -rf /isip/d201/parihar/aurora_sample_decode/exp;
rm -rf /isip/d201/parihar/aurora_sample_decode/report

# create the necessary directories
#
mkdir /isip/d201/parihar/aurora_sample_decode/exp;
mkdir /isip/d201/parihar/aurora_sample_decode/exp/decode;
mkdir /isip/d201/parihar/aurora_sample_decode/exp/decode/output;
mkdir /isip/d201/parihar/aurora_sample_decode/report

# create the states file
#
echo "INFO: converting models to site-specific binary format..."
echo "COMMAND: /isip/tools/util/speech/proto/bin/i386-pc-solaris2.7/convert_mmf -input_mode ascii -output_mode binary /isip/d201/parihar/aurora_sample_decode/data/decode/states.text /isip/d201/parihar/aurora_sample_decode/data/decode/states.bin"
/isip/tools/util/speech/proto/bin/i386-pc-solaris2.7/convert_mmf -input_mode ascii -output_mode binary /isip/d201/parihar/aurora_sample_decode/data/decode/states.text /isip/d201/parihar/aurora_sample_decode/data/decode/states.bin;

# determine what type of architecture we are running so we know whether to 
# swap bytes or not
#
swap_bytes_flag="";

result=`/isip/d201/parihar/aurora_sample_decode/bin/i386-pc-solaris2.7/check_endian`;
if (test "$result" -eq "0")
then
  echo "INFO: big endian architecture found, swapping bytes on feature extraction...";
  swap_bytes_flag="-swap_bytes";
fi

# generate the feature data
#
echo "INFO: creating feature data from raw audio data..."
echo "COMMAND: /isip/tools/util/speech/proto/bin/i386-pc-solaris2.7/extract_feature -delta -acc -cms -zero_mean -energy -energy_norm -mfcc 12 -delta_win 2 -lifter_coeff 22 -window_dur 25 -frame_dur 10 -window_type hamming -sf 16000.0 -mel_width 85.842581 -output_mode binary -pre_emph_coeff 0.97 $swap_bytes_flag -input /isip/d201/parihar/aurora_sample_decode/data/data_generation/lists/decode_raw.list -output /isip/d201/parihar/aurora_sample_decode/data/data_generation/lists/decode_mfc.list"
/isip/tools/util/speech/proto/bin/i386-pc-solaris2.7/extract_feature -delta -acc -cms -zero_mean -energy -energy_norm -mfcc 12 -delta_win 2 -lifter_coeff 22 -window_dur 25 -frame_dur 10 -window_type hamming -sf 16000.0 -mel_width 85.842581 -output_mode binary -pre_emph_coeff 0.97 $swap_bytes_flag -input /isip/d201/parihar/aurora_sample_decode/data/data_generation/lists/decode_raw.list -output /isip/d201/parihar/aurora_sample_decode/data/data_generation/lists/decode_mfc.list;

# run decoding on the generated features
#
echo "INFO: decoding with bigram language model";
echo "COMMAND: /isip/tools/util/speech/proto/bin/i386-pc-solaris2.7/trace_projector -p /isip/d201/parihar/aurora_sample_decode/data/decode/params.text";
/isip/tools/util/speech/proto/bin/i386-pc-solaris2.7/trace_projector -p /isip/d201/parihar/aurora_sample_decode/data/decode/params.text;

# evaluate the results
#
echo "INFO: evaluating results...";
echo "COMMAND: /isip/tools/util/speech/proto/bin/scripts/isip_eval isip_word /isip/d201/parihar/aurora_sample_decode/data/data_generation/lists/decode_output.list /isip/d201/parihar/aurora_sample_decode/data/decode/reference.text /isip/d201/parihar/aurora_sample_decode/exp/decode/results";
/isip/tools/util/speech/proto/bin/scripts/isip_eval isip_word /isip/d201/parihar/aurora_sample_decode/data/data_generation/lists/decode_output.list /isip/d201/parihar/aurora_sample_decode/data/decode/reference.text /isip/d201/parihar/aurora_sample_decode/exp/decode/results;

# grep the performance result from the hypothesis report
#
report_dir="/isip/d201/parihar/aurora_sample_decode/exp/decode"
hypothesis_file="$report_dir/results.report"
tmp_report="$report_dir/tmp.report"
err_file="$report_dir/error.report"

if [ -s $hypothesis_file ]
then
    grep Percent $hypothesis_file > $tmp_report
else
 echo hypothesis report not found  >> $err_file;
fi

if [ -s $err_file ]
then
    more $err_file;
    exit;
fi


# compare the scores and report the difference
#
diff $tmp_report /isip/d201/parihar/aurora_sample_decode/data/reference/reference.report >> $err_file

# check if there is any error
#
if [ -s $err_file ]
then
    echo 'INFO: Error Occured';
    echo 'Check error.report under exp/decode/output/ directory';
    more $err_file;
else

# informational message
#
echo "INFO: Please look in /isip/d201/parihar/aurora_sample_decode/exp for full results";
fi
